@@ -158,6 +158,9 @@ gs_listener_send_signal_active_changed (GSListener *listener)
 
         g_return_if_fail (listener != NULL);
 
+        gs_debug ("Sending the ActiveChanged(%s) signal on the session bus",
+                  listener->priv->active ? "TRUE" : "FALSE");
+
         message = dbus_message_new_signal (GS_LISTENER_PATH,
                                            GS_LISTENER_SERVICE,
                                            "ActiveChanged");
@@ -345,11 +348,6 @@ gs_listener_set_active (GSListener *listener,
 
         listener_set_active_internal (listener, active);
 
-        if (! active) {
-                /* if we are deactivating then reset the throttle */
-                gs_listener_set_throttle_enabled (listener, FALSE);
-        }
-
         return TRUE;
 }
 
