@@ -48,6 +48,7 @@ typedef struct
 {
         GtkWindowClass   parent_class;
 
+        gboolean        (* activity)            (GSWindow *window);
         void            (* deactivated)         (GSWindow *window);
         void            (* dialog_up)           (GSWindow *window);
         void            (* dialog_down)         (GSWindow *window);
@@ -55,6 +56,8 @@ typedef struct
 
 GType       gs_window_get_type           (void);
 
+gboolean    gs_window_is_obscured        (GSWindow  *window);
+
 void        gs_window_set_screen         (GSWindow  *window,
                                           GdkScreen *screen);
 GdkScreen * gs_window_get_screen         (GSWindow  *window);
